CreditCardForm
==============


`CreditCardForm` is a React component that is used to display a credit card form with the following input fields:

* Credit card number
* Credit card expiration date
* Credit card verification code, also known as [CVV](https://en.wikipedia.org/wiki/Card_security_code)
* Credit card holder name
* Credit card holder country
* Credit card holder postal Code

Some of these fields use [masking](https://en.wikipedia.org/wiki/Input_mask), i.e. rules that govern what a user is allowed to enter in a text box.

## Usage

```jsx
import React from 'react';
import CreditCardForm from 'components/upgrades/credit-card-form';

React.createClass( {
	render: function() {
		return (
			<CreditCardForm
				card={ this.props.card }
				countriesList={ this.props.countriesList }
				eventFormName="Credit Card Form"
				isFieldInvalid={ this.isFieldInvalid }
				onFieldChange={ this.onFieldChange } />
		);
	}
} );
```

## Properties

This component makes use of the following properties, which are all required:

### `card`

An object containing a set of input fields as key/value pairs.

### `countriesList`

An object containing a set of countries as code/name pairs.

### `eventFormName`

A string used to distinguish events generated by this form in analytics.

### `isFieldInvalid`

A function that checks if a given field is valid or not. The function is passed the corresponding field name.

### `onFieldChange`

A function invoked when the value of an input field changes. This provides access to the raw value as well as the masked value if the corresponding field.
